/*
 * File devsrv.c
 *
 * Authors Philip Duval (DESY)
 *
 * Copyright (c) Deutsches Elektronen-Synchrotron DESY 1992-2023
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "app_version.h"
#include <stdio.h>
#include <stddef.h>
#include <stdlib.h>
#include "tine.h"

void PreSystemInit(void);
void PostSystemInit(void);

extern char thisLocation[FEC_LOCATION_SIZE];
extern int g_isTerminating;

char *usageText = "usage: gens [/l=<location> /d=<debug level>";
int main(int argc, char *argv[])
{
  int i,cc;
  char *c, scratch[256];

  for (i=1; i<argc; i++)
  { /* options given */
    c = argv[i];
    if (*c++ != '/') break;
    switch (tolower(*c))
    {
      case 'l':
        if ((c=strchr(c,'=')) != NULL)
        {
          c++;
          strncpy(thisLocation,c,FEC_LOCATION_SIZE);
        }
        continue;
      case 'd':
        if ((c=strchr(c,'=')) != NULL)
        {
          c++;
          strncpy(scratch,c,32);
          tineDebug = atoi(scratch);      
        }
        continue;
      case '?':
      case 'h':
        printf("%s",usageText);
        exit(0);
      default:
        continue;
    }
  }
  AssignFecApplicationInfo(APPV_MAJOR,APPV_MINOR,APPV_REVISION);
  SetPreSystemInitFunction(PreSystemInit);
  SetPostSystemInitFunction(PostSystemInit);
  if ((cc=SystemInit(TRUE)) != 0) { printf("init error: %s\n",erlst[cc]); exit(1); }
  for(;;)
  {
    if (g_isTerminating) ttyquit(NULL,NULL);
    SystemCycle(TRUE);
  }
  return 0;
}
